@@ -17,7 +17,7 @@ class DataPlot(object):
     
     """
     def __init__(self, elem=None, spec=None, all_data=[], atom=None, n_tem_points=10000, 
-                 ref_tem=None, OmegaInterp='Cheb',NLevels=None):
+                 ref_tem=None, OmegaInterp='linear',NLevels=None):
         """
     Parameters:
         - elem         atomic elem 
@@ -56,7 +56,7 @@ class DataPlot(object):
         atom_data = []
         coll_data = []
         if all_data == []:
-            all_data = pn.atomicData.getAllAvailableFiles(self.atom)
+            all_data = pn.atomicData.getAllAvailableFiles(self.atom, mark_current=False)
         i_colors = 0    
         for file_ in all_data:
             ID = file_.split('_')[-1]
@@ -238,8 +238,8 @@ class DataPlot(object):
         plt.gca().get_yaxis().get_major_formatter().set_useOffset(False)
         ax.set_xticks(x)
         
-        fig.text(.5, .05, "i (lower level)", fontsize=12, ha='center', color="#660066", va='top')
-        fig.text(.05, .5, "j (upper level)", ha='left', va='center', fontsize=12, color="#660066", rotation=90)
+        #fig.text(.5, .05, "i (lower level)", fontsize=12, ha='center', color="#660066", va='top')
+        #fig.text(.05, .5, "j (upper level)", ha='left', va='center', fontsize=12, color="#660066", rotation=90)
         title = "Available transition probabilities for {0} {1}".format(self.elem, int_to_roman(int(self.spec)))
         fig.text(.5, .95, title, color="#191970", fontsize=14, ha='center')
         for i, data in enumerate(self.atom_data):
