@@ -26,12 +26,19 @@ class _ManageAtomicData(object):
         self._RecombData = {}
         self._initChianti()
         self.read_gsconf()        
-        
+        self.usedFiles = {} 
+    
     def includeFitsPath(self):
         self.addDataFilePath('atomic_data_fits/old_fits/', inPyNeb=True)
 
     def removeFitsPath(self):
         self.removeDataFilePath('atomic_data_fits/old_fits/')
+
+    def includeDeprecatedPath(self):
+        self.addDataFilePath('atomic_data/deprecated/', inPyNeb=True)
+
+    def removeDeprecatedPath(self):
+        self.removeDataFilePath('atomic_data/deprecated/')
         
     def getPredefinedDataFileDict(self, data_dict=None):
         """
@@ -189,7 +196,7 @@ class _ManageAtomicData(object):
                 print('{0} rec from {1} in {2}'.format(atom, rec_file , self.getDirForFile(rec_file)))
  
  
-    def getAllAvailableFiles(self, atom=None, data_type=None):
+    def getAllAvailableFiles(self, atom=None, data_type=None, mark_current=True):
         """
         Scan every directory in the list of paths, printing all the *atom*.fits, *atom*.dat,
             *coll*.fits and *rec*.fits files
@@ -197,9 +204,15 @@ class _ManageAtomicData(object):
         Parameters:
            - atom        atom name
            - data_type   either 'rec', 'atom', 'coll' or 'trc'
+           - mark_current: if True, a* is printed before the currently used datafile
 
         """
         file_list = []
+        used_files_list = []
+        used_files_dic = pn.atomicData.getDataFile()    
+        for a in used_files_dic: 
+            for k in used_files_dic[a]: 
+                used_files_list.append(used_files_dic[a][k])         
         if data_type is None:
             data_types = ['atom', 'coll', 'rec', 'trc']
         else:
@@ -211,10 +224,16 @@ class _ManageAtomicData(object):
             atom_str = '{0}_{1}_'.format(elem, spec)
             if atom2chianti(atom) in self.ChiantiIONS['atom']:
                 if 'atom' in data_types:
-                    file_list.append('{0}_{1}_atom.chianti'.format(elem, spec))
+                    ff = '{0}_{1}_atom.chianti'.format(elem, spec)
+                    if ff in used_files_list and mark_current:
+                        ff = '* ' + ff
+                    file_list.append(ff)
             if atom2chianti(atom) in self.ChiantiIONS['coll']:
                 if 'coll' in data_types:
-                    file_list.append('{0}_{1}_coll.chianti'.format(elem, spec))
+                    ff = '{0}_{1}_coll.chianti'.format(elem, spec)
+                    if ff in used_files_list and mark_current:
+                        ff = '* ' + ff
+                    file_list.append(ff)
         else:
             atom_str = '.'
             for atom in self.ChiantiIONS['atom']:
@@ -222,21 +241,28 @@ class _ManageAtomicData(object):
                 elem = elem.lower()
                 spec = int_to_roman(int(spec)).lower()
                 if 'atom' in data_types:
-                    file_list.append('{0}_{1}_atom.chianti'.format(elem, spec))
+                    ff = '{0}_{1}_atom.chianti'.format(elem, spec)
+                    if ff in used_files_list and mark_current:
+                        ff = '* ' + ff
+                    file_list.append(ff)
             for atom in self.ChiantiIONS['coll']:
                 elem, spec = parseAtom(atom)
                 elem = elem.lower()
                 spec = int_to_roman(int(spec)).lower()
                 if 'coll' in data_types:
-                    file_list.append('{0}_{1}_coll.chianti'.format(elem, spec))
+                    ff = '{0}_{1}_coll.chianti'.format(elem, spec)
+                    if ff in used_files_list and mark_current:
+                        ff = '* ' + ff
+                    file_list.append(ff)
         for dir in self._DataFilePaths:
             files = os.listdir(dir)
-            for file in files:
-                if (('.fits' in file) or ('.func' in file) or ('.hdf5' in file) or ('.dat' in file) ) and (atom_str in file):
+            for ff in files:
+                if (('.fits' in ff) or ('.func' in ff) or ('.hdf5' in ff) or ('.dat' in ff) ) and (atom_str in ff):
                     for dt in data_types:
-                        if dt in file:
-                            file_list.append(file)
-                            
+                        if dt in ff:
+                            if ff in used_files_list and mark_current:
+                                ff = '* ' + ff
+                            file_list.append(ff)
         file_list.sort()
         return file_list
     
@@ -426,7 +452,9 @@ class _ManageAtomicData(object):
         else:
             av_data = self.getAllAvailableFiles(atom, data_type)
             self.log_.error("""Unknown file {0} or corresponding File path not included in list. 
-You may mean one of these files: {1}""".format(data_file, av_data),
+Your file may be deprecated: run pn.atomicData.includeDeprecatedPath() and try again.
+Or your file may be in the fits diectory: run pn.atomicData.includeFitsPath() and try again.                                  
+Or you may mean one of these files: {1}""".format(data_file, av_data),
                            calling=self.calling)
         if (atom == 'H1') and ('H1' in pn.atomicData._RecombData):
             del pn.atomicData._RecombData['H1']
@@ -447,7 +475,7 @@ You may mean one of these files: {1}""".format(data_file, av_data),
                        
         """        
         self.calling = 'printAllSources'
-        if (type(at_set) == list) or (type(at_set) == tuple):
+        if (type(at_set) == list) or (type(at_set) == tuple) or at_set == '':
             at_dict = {}
             for item in at_set:
                 atom = parseAtom(item)[0]
@@ -541,6 +569,13 @@ You may mean one of these files: {1}""".format(data_file, av_data),
         except:
             self.gsconf = {}
         
+    def add2usedFiles(self, atom, file):
+        if atom not in self.usedFiles:
+            self.usedFiles[atom] = [file]
+        elif file not in self.usedFiles[atom]:
+            self.usedFiles[atom].append(file)
+
+
     def printPoem(self, yr=0):
         """
         Print one of Wiese et al. spectroscopic poems
@@ -671,10 +706,10 @@ def getLevelsNIST(atom, NLevels = None):
     else:
         return None
     
-def getNIST(elem, ion, fileout=None):
+def _getNIST(elem, ion, fileout=None):
     """
     This will download the enegy levels from NIST and write them to a file
-    example: getNIST('O',3) write the o_iii_levels.dat file
+    example: _getNIST('O',3) write the o_iii_levels.dat file
     """
     
     try:
